@@ -6,11 +6,11 @@ import ssl
 import time
 import warnings
 import webbrowser
+import base64
 from getpass import getpass
 from http.server import (
     BaseHTTPRequestHandler,
     HTTPServer,
-    SimpleHTTPRequestHandler,
 )
 
 import tqdm
@@ -43,6 +43,28 @@ except ImportError:
     pass
 
 
+def unvalidated_token_parse(token):
+    try:
+        import jwt
+        try:
+            # Cope with both versions of pyJWT's api
+            if jwt.__version__.split(".")[0] >= "2":
+                o = jwt.decode(token, options={"verify_signature": False})
+            else:
+                o = jwt.decode(token, verify=False)
+        except jwt.PyJWTError as e:
+            raise ValueError("Unable to parse token") from e
+    except ImportError:
+        try:
+            # Fallback to manual parsing when jwt not installed, as this doesn't need to validate it
+            h, b, s = token.split(".")
+            o = json.loads(base64.urlsafe_b64decode(b + '=='))
+        except (ValueError, IndexError, TypeError) as e:
+            raise ValueError("Unable to parse token") from e
+
+    return o
+
+
 class SystemSSLContextAdapter(HTTPAdapter):
     """
     By default requests uses the SSL CA bundle installed by certifi or, failing
@@ -76,8 +98,6 @@ setTimeout(function(){window.close()}, 500);
 </script>
 </body>
 </html>
-
-
 """
 
 
@@ -91,6 +111,8 @@ class Configuration(client.Configuration):
         offline=False,
         host=None,
     ):
+        super(Configuration, self).__init__(host=host)
+
         self.grant_type = grant_type
         self.client_id = client_id
         self.client_secret = ""
@@ -103,7 +125,6 @@ class Configuration(client.Configuration):
         self._proxy = None
         self._auth_backoff = False
 
-        super(Configuration, self).__init__(host=host)
 
     @property
     def token_endpoint(self):
@@ -189,6 +210,21 @@ class Configuration(client.Configuration):
         )
         return token
 
+    def _check_returned_token(self, token):
+        if self.username:
+            try:
+                o = unvalidated_token_parse(token['access_token'])
+            except ValueError:
+                # Ignore parse errors
+                return
+            if "preferred_username" not in o:
+                return
+            if o['preferred_username'] != self.username:
+                raise RuntimeError(
+                    "Login token doesn't match expected username. "
+                    f"Expected '{self.username}', received '{o['preferred_username']}'. Aborting"
+                )
+
     def _get_token_authorisation(self):
         """
         Performs oauth standard/authorisation_code flow by launching local
@@ -232,6 +268,7 @@ class Configuration(client.Configuration):
             client_id=self.client_id,
             verify=self.verify_ssl,
         )
+        self._check_returned_token(token)
         return token
 
     def try_offline(self):
@@ -244,6 +281,7 @@ class Configuration(client.Configuration):
                 try:
                     self.token["refresh_token"] = offline_token
                     self.refresh_token()
+                    self._check_returned_token(self.token)
                     return True
                 except (ValueError, OAuth2Error):
                     return False
