@@ -140,12 +140,16 @@ from alchemite_apiclient.model.historic_vector_prediction import HistoricVectorP
 from alchemite_apiclient.model.historic_vector_value import HistoricVectorValue
 from alchemite_apiclient.model.importance_request import ImportanceRequest
 from alchemite_apiclient.model.impute_request import ImputeRequest
+from alchemite_apiclient.model.inline_object import InlineObject
 from alchemite_apiclient.model.inline_response200 import InlineResponse200
 from alchemite_apiclient.model.inline_response2001 import InlineResponse2001
 from alchemite_apiclient.model.inline_response2002 import InlineResponse2002
 from alchemite_apiclient.model.inline_response2003 import InlineResponse2003
+from alchemite_apiclient.model.inline_response2003_values import InlineResponse2003Values
 from alchemite_apiclient.model.inline_response2004 import InlineResponse2004
+from alchemite_apiclient.model.inline_response2005 import InlineResponse2005
 from alchemite_apiclient.model.int_cat_arr import IntCatArr
+from alchemite_apiclient.model.interaction_plot_data import InteractionPlotData
 from alchemite_apiclient.model.job_favourite_query import JobFavouriteQuery
 from alchemite_apiclient.model.job_patch import JobPatch
 from alchemite_apiclient.model.job_query import JobQuery
@@ -235,6 +239,7 @@ from alchemite_apiclient.model.part_tar_fn_categoricals import PartTarFnCategori
 from alchemite_apiclient.model.part_tar_fn_single_tar import PartTarFnSingleTar
 from alchemite_apiclient.model.part_tar_fn_sum import PartTarFnSum
 from alchemite_apiclient.model.part_tar_fn_weighted_sum import PartTarFnWeightedSum
+from alchemite_apiclient.model.predict_interaction_request import PredictInteractionRequest
 from alchemite_apiclient.model.predict_request import PredictRequest
 from alchemite_apiclient.model.predict_trendline_request import PredictTrendlineRequest
 from alchemite_apiclient.model.prediction import Prediction
