@@ -1,9 +1,3 @@
-from __future__ import print_function
-
-import time
-
-import tqdm
-
 import alchemite_apiclient as client
 from alchemite_apiclient.extensions import Configuration
 
@@ -18,5 +12,7 @@ api_default = client.DefaultApi(client.ApiClient(configuration))
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
