@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 from io import StringIO
 
@@ -30,7 +28,9 @@ model_name = "steels"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
