@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 import json
 from io import StringIO
@@ -19,28 +17,18 @@ api_datasets = client.DatasetsApi(client.ApiClient(configuration))
 ### Provide path to the JSON containing your credentials
 configuration.credentials = "credentials.json"
 
-SUGGEST_DATASET = "steels"  # 'steels' or 'vector'
-
-if SUGGEST_DATASET == "steels":
-    dataset_file = "steels.csv"
-    dataset_name = "steels"
-    model_name = "steels"
-    suggest_args = "suggest_additional_args_steel.json"
-    vector_pairs = None
-elif SUGGEST_DATASET == "vector":
-    dataset_file = "vector.csv"
-    dataset_name = "vector"
-    model_name = "vector"
-    suggest_args = "suggest_additional_args_vector.json"
-    vector_pairs = [["z", "t"]]
-else:
-    raise Exception("Invalid suggest dataset option")
+dataset_file = "steels.csv"
+dataset_name = "steels"
+model_name = "steels"
+suggest_args = "suggest_additional_args_steel.json"
 
 # Check we can access the API by getting the version number from GET /version
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
@@ -60,7 +48,6 @@ dataset = {
     # No descriptors in this dataset so list of zeros
     "descriptor_columns": [0] * len(column_headers),
     "data": data,
-    "vector_pairs": vector_pairs,
 }
 dataset_id = api_datasets.datasets_post(dataset=dataset)
 print("dataset ID:", dataset_id)
@@ -125,6 +112,7 @@ suggest_additional_job_id = api_models.models_id_suggest_additional_post(
 )
 print("suggest_additional job ID:", suggest_additional_job_id)
 
+
 # Wait until the suggest_additional job has finished
 def get_suggest_additional_job_metadata():
     return api_models.models_id_suggest_additional_job_id_get(
