@@ -85,6 +85,11 @@ def pytest_configure(config):
             ["steels.csv", "suggest_additional_args_steel.json"],
             id="suggest_additional",
         ),
+        pytest.param(
+            "constraints",
+            ["steels.csv", "suggest_additional_args_composition.json"],
+            id="constraints",
+        ),
         pytest.param(
             "suggest_historic",
             ["steels.csv", "suggest_historic_args_steel.json"],
@@ -111,12 +116,7 @@ def pytest_configure(config):
             id="validate",
         ),
         pytest.param(
-            "vector",
-            ["vector.csv"],
-            id="vector",
-        ),
-        pytest.param(
-            "validation_request", ["steels.csv"], id="validation_request"
+            "validation_predictions", ["steels.csv"], id="validation_predictions"
         ),
         pytest.param("histogram", ["steels.csv"], id="histogram"),
     ],
